
# Espressif Documentation Build System

Esp-docs is a python based wrapper for the documentation building package Sphinx.

It is intended to simplify and extend Sphinx's functionality to better suit what is needed for building documentation for Espressif's development frameworks

Provides:
 * Functionality for building documentation for multiple targets (e.g. ESP32 and ESP32-C3) from the same rst source files.
 * Sphinx extensions used at Espressif
 * Scripts for deploying docs

For a more indepth guide on how to install, write and compile documentation please see [writing-documention](docs/writing-documention.md) and [building-documention](docs/building-documention.md).
